/*
export function someAction (context) {
}
*/
import firebase from "firebase/app";

import { firestoreAction } from "vuexfire";

export const setProjectsRef = firestoreAction(
  ({ bindFirestoreRef, commit }, ref) => {
    return bindFirestoreRef("projects", ref);
  }
);

export const setCategoryRef = firestoreAction(
  ({ bindFirestoreRef, commit }, ref) => {
    return bindFirestoreRef("category", ref);
  }
);

export function loadAllProjects({ state, dispatch }) {
  const db = firebase.firestore();

  var ref = db
    .collection("projects")
    .where("status", "==", "published")
    .orderBy("created", "desc");

  dispatch("setProjectsRef", ref);
}

export function loadCategory({ state, dispatch }, category_id) {
  const db = firebase.firestore();

  var projects_ref = db
    .collection("projects")
    .where("status", "==", "published")
    .where("category_id", "==", category_id);

  var cat_ref = db.collection("categories").doc(category_id);

  dispatch("setProjectsRef", projects_ref);
  dispatch("setCategoryRef", cat_ref);
}

export const loadLatestProjects = firestoreAction(({ bindFirestoreRef }) => {
  const db = firebase.firestore();
  const ref = db
    .collection("projects")
    .where("status", "==", "published")
    .orderBy("created", "desc")
    .limit(6);
  return bindFirestoreRef("latestProjects", ref);
});

export const loadFeaturedProjects = firestoreAction(({ bindFirestoreRef }) => {
  const db = firebase.firestore();
  const ref = db
    .collection("projects")
    .where("status", "==", "published")
    .where("featured", "==", true)
    .orderBy("created", "desc")
    .limit(6);
  return bindFirestoreRef("featuredProjects", ref);
  // dispatch("setFeaturedProjectsRef", ref);
});

export const loadPopularProjects = firestoreAction(({ bindFirestoreRef }) => {
  const db = firebase.firestore();
  const ref = db
    .collection("projects")
    .where("status", "==", "published")
    .orderBy("downloadsCount", "desc")
    .limit(6);
  return bindFirestoreRef("popularProjects", ref);
  // dispatch("setFeaturedProjectsRef", ref);
});
